@@ -3,13 +3,14 @@ use v6;
 use PDF::COS::Dict;
 use PDF::Class::Type;
 
-# /Type /Group - a node in the page tree
+# /Type /Group - group attributes dictionary
 class PDF::Group
     is PDF::COS::Dict
     does PDF::Class::Type['Type','S'] {
 
-    # see [PDF 1.7 TABLE 10.12 Entries in an object reference dictionary]
+    # see [Table 96 – Entries Common to all Group Attributes Dictionaries]
     use PDF::COS::Tie;
     use PDF::COS::Name;
-    has PDF::COS::Name $.Type is entry(:required) where 'Group';
+
+    has PDF::COS::Name $.Type is entry where 'Group';
 }
